package com.serbia.webadmin.app.dto;

import com.serbia.common.core.validator.UpdateGroup;

import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;

import jakarta.validation.constraints.*;

/**
 * 聊天群组管理Dto对象。
 *
 * @author 吃饭睡觉
 * @date 2024-12-10
 */
@Schema(description = "聊天群组管理Dto对象")
@Data
public class SerbiaGroupsDto {

    /**
     * 主键id。
     * NOTE: 可支持等于操作符的列表数据过滤。
     */
    @Schema(description = "主键id。可支持等于操作符的列表数据过滤。", requiredMode = Schema.RequiredMode.REQUIRED)
    @NotNull(message = "数据验证失败，主键id不能为空！", groups = {UpdateGroup.class})
    private Long groupId;

    /**
     * 群主id。
     * NOTE: 可支持等于操作符的列表数据过滤。
     */
    @Schema(description = "群主id。可支持等于操作符的列表数据过滤。", requiredMode = Schema.RequiredMode.REQUIRED)
    @NotNull(message = "数据验证失败，群主id不能为空！")
    private Long groupOwnerId;

    /**
     * 群聊名称。
     * NOTE: 可支持等于操作符的列表数据过滤。
     */
    @Schema(description = "群聊名称。可支持等于操作符的列表数据过滤。", requiredMode = Schema.RequiredMode.REQUIRED)
    @NotBlank(message = "数据验证失败，群聊名称不能为空！")
    private String groupName;

    /**
     * 群聊头像。
     */
    @Schema(description = "群聊头像。")
    private String groupAvatar;

    /**
     * 是否公开 0私密 1公开。
     * NOTE: 可支持等于操作符的列表数据过滤。
     */
    @Schema(description = "是否私密 0公开 1私密。可支持等于操作符的列表数据过滤。")
    private Integer isPrivate;

    /**
     * createTime 范围过滤起始值(>=)。
     * NOTE: 可支持范围操作符的列表数据过滤。
     */
    @Schema(description = "createTime 范围过滤起始值(>=)。可支持范围操作符的列表数据过滤。")
    private String createTimeStart;

    /**
     * createTime 范围过滤结束值(<=)。
     * NOTE: 可支持范围操作符的列表数据过滤。
     */
    @Schema(description = "createTime 范围过滤结束值(<=)。可支持范围操作符的列表数据过滤。")
    private String createTimeEnd;

    /**
     * updateTime 范围过滤起始值(>=)。
     * NOTE: 可支持范围操作符的列表数据过滤。
     */
    @Schema(description = "updateTime 范围过滤起始值(>=)。可支持范围操作符的列表数据过滤。")
    private String updateTimeStart;

    /**
     * updateTime 范围过滤结束值(<=)。
     * NOTE: 可支持范围操作符的列表数据过滤。
     */
    @Schema(description = "updateTime 范围过滤结束值(<=)。可支持范围操作符的列表数据过滤。")
    private String updateTimeEnd;

    /**
     * group_name LIKE搜索字符串。
     * NOTE: 可支持LIKE操作符的列表数据过滤。
     */
    @Schema(description = "LIKE模糊搜索字符串")
    private String searchString;
}
