package com.serbia.webadmin.app.dto;

import com.serbia.common.core.validator.UpdateGroup;

import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;

import jakarta.validation.constraints.*;

/**
 * 聊天信息管理Dto对象。
 *
 * @author 吃饭睡觉
 * @date 2024-12-10
 */
@Schema(description = "聊天信息管理Dto对象")
@Data
public class SerbiaMessagesDto {

    /**
     * 主键id。
     * NOTE: 可支持等于操作符的列表数据过滤。
     */
    @Schema(description = "主键id。可支持等于操作符的列表数据过滤。", requiredMode = Schema.RequiredMode.REQUIRED)
    @NotNull(message = "数据验证失败，主键id不能为空！", groups = {UpdateGroup.class})
    private Long messageId;

    /**
     * 发送人id。
     * NOTE: 可支持等于操作符的列表数据过滤。
     */
    @Schema(description = "发送人id。可支持等于操作符的列表数据过滤。", requiredMode = Schema.RequiredMode.REQUIRED)
    @NotNull(message = "数据验证失败，发送人id不能为空！")
    private Long senderId;

    /**
     * 接收者id。
     * NOTE: 可支持等于操作符的列表数据过滤。
     */
    @Schema(description = "接收者id。可支持等于操作符的列表数据过滤。", requiredMode = Schema.RequiredMode.REQUIRED)
    @NotNull(message = "数据验证失败，接收者id不能为空！")
    private Long receiverId;

    /**
     * 群组id。
     * NOTE: 可支持等于操作符的列表数据过滤。
     */
    @Schema(description = "群组id。可支持等于操作符的列表数据过滤。")
    private Long groupId;

    /**
     * 消息类型 1文字 2图片 3文件。
     * NOTE: 可支持等于操作符的列表数据过滤。
     */
    @Schema(description = "消息类型 1文字 2图片 3文件。可支持等于操作符的列表数据过滤。", requiredMode = Schema.RequiredMode.REQUIRED)
    @NotNull(message = "数据验证失败，消息类型 1文字 2图片 3文件不能为空！")
    private Integer messsageType;

    /**
     * 消息内容。
     * NOTE: 可支持等于操作符的列表数据过滤。
     */
    @Schema(description = "消息内容。可支持等于操作符的列表数据过滤。", requiredMode = Schema.RequiredMode.REQUIRED)
    @NotBlank(message = "数据验证失败，消息内容不能为空！")
    private String messageContent;

    /**
     * 消息已读状态 0未读 1已读。
     * NOTE: 可支持等于操作符的列表数据过滤。
     */
    @Schema(description = "消息已读状态 0未读 1已读。可支持等于操作符的列表数据过滤。", requiredMode = Schema.RequiredMode.REQUIRED)
    @NotNull(message = "数据验证失败，消息已读状态 0未读 1已读不能为空！", groups = {UpdateGroup.class})
    private Integer readStatus;

    /**
     * createTime 范围过滤起始值(>=)。
     * NOTE: 可支持范围操作符的列表数据过滤。
     */
    @Schema(description = "createTime 范围过滤起始值(>=)。可支持范围操作符的列表数据过滤。")
    private String createTimeStart;

    /**
     * createTime 范围过滤结束值(<=)。
     * NOTE: 可支持范围操作符的列表数据过滤。
     */
    @Schema(description = "createTime 范围过滤结束值(<=)。可支持范围操作符的列表数据过滤。")
    private String createTimeEnd;

    /**
     * message_content LIKE搜索字符串。
     * NOTE: 可支持LIKE操作符的列表数据过滤。
     */
    @Schema(description = "LIKE模糊搜索字符串")
    private String searchString;
}
