package com.serbia.webadmin.app.model;

import com.baomidou.mybatisplus.annotation.*;
import com.serbia.common.core.util.MyCommonUtil;
import com.serbia.common.core.upload.UploadStoreTypeEnum;
import com.serbia.common.core.annotation.*;
import com.serbia.common.core.base.model.BaseModel;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.util.Map;

/**
 * 聊天群组管理实体对象。
 *
 * @author 吃饭睡觉
 * @date 2024-12-10
 */
@Data
@EqualsAndHashCode(callSuper = true)
@TableName(value = "serbia_groups")
public class SerbiaGroups extends BaseModel {

    /**
     * 主键id。
     */
    @TableId(value = "group_id")
    private Long groupId;

    /**
     * 群主id。
     */
    @TableField(value = "group_owner_id")
    private Long groupOwnerId;

    /**
     * 群聊名称。
     */
    @TableField(value = "group_name")
    private String groupName;

    /**
     * 群聊头像。
     */
    @UploadFlagColumn(storeType = UploadStoreTypeEnum.HUAWEI_OBS_SYSTEM)
    @TableField(value = "group_avatar")
    private String groupAvatar;

    /**
     * 是否公开 0私密 1公开。
     */
    @TableField(value = "is_private")
    private Integer isPrivate;

    /**
     * 逻辑删除标记字段(1: 正常 -1: 已删除)。
     */
    @TableLogic
    @TableField(value = "data_state")
    private Integer dataState;

    /**
     * createTime 范围过滤起始值(>=)。
     */
    @TableField(exist = false)
    private String createTimeStart;

    /**
     * createTime 范围过滤结束值(<=)。
     */
    @TableField(exist = false)
    private String createTimeEnd;

    /**
     * updateTime 范围过滤起始值(>=)。
     */
    @TableField(exist = false)
    private String updateTimeStart;

    /**
     * updateTime 范围过滤结束值(<=)。
     */
    @TableField(exist = false)
    private String updateTimeEnd;

    /**
     * group_name LIKE搜索字符串。
     */
    @TableField(exist = false)
    private String searchString;

    public void setSearchString(String searchString) {
        this.searchString = MyCommonUtil.replaceSqlWildcard(searchString);
    }

    @RelationGlobalDict(
            masterIdField = "isPrivate",
            dictCode = "YesOrNo")
    @TableField(exist = false)
    private Map<String, Object> isPrivateDictMap;
}
