package com.serbia.webadmin.app.model;

import com.baomidou.mybatisplus.annotation.*;
import com.serbia.common.core.util.MyCommonUtil;
import com.serbia.common.core.annotation.*;
import lombok.Data;

import java.util.Date;
import java.util.Map;

/**
 * 聊天信息管理实体对象。
 *
 * @author 吃饭睡觉
 * @date 2024-12-10
 */
@Data
@TableName(value = "serbia_messages")
public class SerbiaMessages {

    /**
     * 主键id。
     */
    @TableId(value = "message_id")
    private Long messageId;

    /**
     * 发送人id。
     */
    @TableField(value = "sender_id")
    private Long senderId;

    /**
     * 接收者id。
     */
    @TableField(value = "receiver_id")
    private Long receiverId;

    /**
     * 群组id。
     */
    @TableField(value = "group_id")
    private Long groupId;

    /**
     * 消息类型 1文字 2图片 3文件。
     */
    @TableField(value = "messsage_type")
    private Integer messsageType;

    /**
     * 消息内容。
     */
    @TableField(value = "message_content")
    private String messageContent;

    /**
     * 创建时间。
     */
    @TableField(value = "create_time")
    private Date createTime;

    /**
     * 更新用户。
     */
    @TableField(value = "update_user_id")
    private Long updateUserId;

    /**
     * 更新时间。
     */
    @TableField(value = "update_time")
    private Date updateTime;

    /**
     * 逻辑删除标记字段(1: 正常 -1: 已删除)。
     */
    @TableLogic
    @TableField(value = "data_state")
    private Integer dataState;

    /**
     * 消息已读状态 0未读 1已读。
     */
    @TableField(value = "read_status")
    private Integer readStatus;

    /**
     * createTime 范围过滤起始值(>=)。
     */
    @TableField(exist = false)
    private String createTimeStart;

    /**
     * createTime 范围过滤结束值(<=)。
     */
    @TableField(exist = false)
    private String createTimeEnd;

    /**
     * message_content LIKE搜索字符串。
     */
    @TableField(exist = false)
    private String searchString;

    public void setSearchString(String searchString) {
        this.searchString = MyCommonUtil.replaceSqlWildcard(searchString);
    }

    @RelationGlobalDict(
            masterIdField = "messsageType",
            dictCode = "MessageType")
    @TableField(exist = false)
    private Map<String, Object> messsageTypeDictMap;

    @RelationGlobalDict(
            masterIdField = "readStatus",
            dictCode = "MessageReadStatus")
    @TableField(exist = false)
    private Map<String, Object> readStatusDictMap;
}
