package com.serbia.webadmin.app.model;

import com.baomidou.mybatisplus.annotation.*;
import com.serbia.webadmin.upms.model.constant.SysUserStatus;
import com.serbia.common.core.util.MyCommonUtil;
import com.serbia.common.core.upload.UploadStoreTypeEnum;
import com.serbia.common.core.annotation.*;
import com.serbia.common.core.base.model.BaseModel;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.util.Date;
import java.util.Map;

/**
 * 塞尔用户管理实体对象。
 *
 * @author 吃饭睡觉
 * @date 2024-12-10
 */
@Data
@EqualsAndHashCode(callSuper = true)
@TableName(value = "serbia_users")
public class SerbiaUsers extends BaseModel {

    /**
     * 主键Id。
     */
    @TableId(value = "user_id")
    private Long userId;

    /**
     * 用户登录名称。
     */
    @TableField(value = "login_name")
    private String loginName;

    /**
     * 密码。
     */
    @TableField(value = "password")
    private String password;

    /**
     * 昵称。
     */
    @TableField(value = "show_name")
    private String showName;

    /**
     * 用户头像的Url。
     */
    @UploadFlagColumn(storeType = UploadStoreTypeEnum.HUAWEI_OBS_SYSTEM)
    @TableField(value = "head_image_url")
    private String headImageUrl;

    /**
     * 状态(0: 正常 1: 锁定)。
     */
    @TableField(value = "user_status")
    private Integer userStatus;

    /**
     * 用户邮箱。
     */
    @TableField(value = "email")
    private String email;

    /**
     * 用户手机。
     */
    @TableField(value = "mobile")
    private String mobile;

    /**
     * 性别(1:男 2:女 3:其它)。
     */
    @TableField(value = "sex")
    private String sex;

    /**
     * 生日。
     */
    @TableField(value = "birthday")
    private Date birthday;

    /**
     * 逻辑删除标记字段(1: 正常 -1: 已删除)。
     */
    @TableLogic
    @TableField(value = "deleted_flag")
    private Integer deletedFlag;

    /**
     * 手机号所属国家code。
     */
    @TableField(value = "country_code")
    private String countryCode;

    /**
     * 住址。
     */
    @TableField(value = "address")
    private String address;

    /**
     * 职业。
     */
    @TableField(value = "job")
    private String job;

    /**
     * 个性签名。
     */
    @TableField(value = "personal_sign")
    private String personalSign;

    /**
     * createTime 范围过滤起始值(>=)。
     */
    @TableField(exist = false)
    private String createTimeStart;

    /**
     * createTime 范围过滤结束值(<=)。
     */
    @TableField(exist = false)
    private String createTimeEnd;

    /**
     * login_name / show_name / email / mobile / sex / address / job LIKE搜索字符串。
     */
    @TableField(exist = false)
    private String searchString;

    public void setSearchString(String searchString) {
        this.searchString = MyCommonUtil.replaceSqlWildcard(searchString);
    }

    @RelationConstDict(
            masterIdField = "userStatus",
            constantDictClass = SysUserStatus.class)
    @TableField(exist = false)
    private Map<String, Object> userStatusDictMap;

    @RelationGlobalDict(
            masterIdField = "sex",
            dictCode = "UserSex")
    @TableField(exist = false)
    private Map<String, Object> sexDictMap;
}
