package com.serbia.webadmin.app.service;

import com.serbia.webadmin.app.model.*;
import com.serbia.common.core.base.service.IBaseService;

import java.util.*;

/**
 * 塞尔用户管理数据操作服务接口。
 *
 * @author 吃饭睡觉
 * @date 2024-12-10
 */
public interface SerbiaUsersService extends IBaseService<SerbiaUsers, Long> {

    /**
     * 保存新增对象。
     *
     * @param serbiaUsers 新增对象。
     * @return 返回新增对象。
     */
    SerbiaUsers saveNew(SerbiaUsers serbiaUsers);

    /**
     * 利用数据库的insertList语法，批量插入对象列表。
     *
     * @param serbiaUsersList 新增对象列表。
     */
    void saveNewBatch(List<SerbiaUsers> serbiaUsersList);

    /**
     * 更新数据对象。
     *
     * @param serbiaUsers         更新的对象。
     * @param originalSerbiaUsers 原有数据对象。
     * @return 成功返回true，否则false。
     */
    boolean update(SerbiaUsers serbiaUsers, SerbiaUsers originalSerbiaUsers);

    /**
     * 删除指定数据。
     *
     * @param userId 主键Id。
     * @return 成功返回true，否则false。
     */
    boolean remove(Long userId);

    /**
     * 获取单表查询结果。由于没有关联数据查询，因此在仅仅获取单表数据的场景下，效率更高。
     * 如果需要同时获取关联数据，请移步(getSerbiaUsersListWithRelation)方法。
     *
     * @param filter  过滤对象。
     * @param orderBy 排序参数。
     * @return 查询结果集。
     */
    List<SerbiaUsers> getSerbiaUsersList(SerbiaUsers filter, String orderBy);

    /**
     * 获取主表的查询结果，以及主表关联的字典数据和一对一从表数据，以及一对一从表的字典数据。
     * 该查询会涉及到一对一从表的关联过滤，或一对多从表的嵌套关联过滤，因此性能不如单表过滤。
     * 如果仅仅需要获取主表数据，请移步(getSerbiaUsersList)，以便获取更好的查询性能。
     *
     * @param filter 主表过滤对象。
     * @param orderBy 排序参数。
     * @return 查询结果集。
     */
    List<SerbiaUsers> getSerbiaUsersListWithRelation(SerbiaUsers filter, String orderBy);


    /**
     * 修改用户头像。
     *
     * @param userId  用户主键Id。
     * @param newHeadImage 新的头像信息。
     * @return 成功返回true，否则false。
     */
    boolean changeHeadImage(Long userId, String newHeadImage);
}
