package com.serbia.webadmin.app.service.impl;

import cn.hutool.core.collection.CollUtil;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.serbia.webadmin.app.service.*;
import com.serbia.webadmin.app.dao.*;
import com.serbia.webadmin.app.model.*;
import com.serbia.common.core.base.dao.BaseDaoMapper;
import com.serbia.common.core.constant.GlobalDeletedFlag;
import com.serbia.common.core.object.MyRelationParam;
import com.serbia.common.core.base.service.BaseService;
import com.serbia.common.core.util.MyModelUtil;
import com.serbia.common.sequence.wrapper.IdGeneratorWrapper;
import com.github.pagehelper.Page;
import lombok.extern.slf4j.Slf4j;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

/**
 * 国家区域编码管理数据操作服务类。
 *
 * @author 吃饭睡觉
 * @date 2024-12-10
 */
@Slf4j
@Service("serbiaCountryCodeService")
public class SerbiaCountryCodeServiceImpl extends BaseService<SerbiaCountryCode, Long> implements SerbiaCountryCodeService {

    @Autowired
    private IdGeneratorWrapper idGenerator;
    @Autowired
    private SerbiaCountryCodeMapper serbiaCountryCodeMapper;

    /**
     * 返回当前Service的主表Mapper对象。
     *
     * @return 主表Mapper对象。
     */
    @Override
    protected BaseDaoMapper<SerbiaCountryCode> mapper() {
        return serbiaCountryCodeMapper;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public SerbiaCountryCode saveNew(SerbiaCountryCode serbiaCountryCode) {
        serbiaCountryCodeMapper.insert(this.buildDefaultValue(serbiaCountryCode));
        return serbiaCountryCode;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void saveNewBatch(List<SerbiaCountryCode> serbiaCountryCodeList) {
        if (CollUtil.isNotEmpty(serbiaCountryCodeList)) {
            serbiaCountryCodeList.forEach(this::buildDefaultValue);
            serbiaCountryCodeMapper.insertList(serbiaCountryCodeList);
        }
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean update(SerbiaCountryCode serbiaCountryCode, SerbiaCountryCode originalSerbiaCountryCode) {
        MyModelUtil.fillCommonsForUpdate(serbiaCountryCode, originalSerbiaCountryCode);
        // 这里重点提示，在执行主表数据更新之前，如果有哪些字段不支持修改操作，请用原有数据对象字段替换当前数据字段。
        UpdateWrapper<SerbiaCountryCode> uw = this.createUpdateQueryForNullValue(serbiaCountryCode, serbiaCountryCode.getId());
        return serbiaCountryCodeMapper.update(serbiaCountryCode, uw) == 1;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean remove(Long id) {
        return serbiaCountryCodeMapper.deleteById(id) == 1;
    }

    @Override
    public List<SerbiaCountryCode> getSerbiaCountryCodeList(SerbiaCountryCode filter, String orderBy) {
        return serbiaCountryCodeMapper.getSerbiaCountryCodeList(filter, orderBy);
    }

    @Override
    public List<SerbiaCountryCode> getSerbiaCountryCodeListWithRelation(SerbiaCountryCode filter, String orderBy) {
        List<SerbiaCountryCode> resultList = serbiaCountryCodeMapper.getSerbiaCountryCodeList(filter, orderBy);
        // 在缺省生成的代码中，如果查询结果resultList不是Page对象，说明没有分页，那么就很可能是数据导出接口调用了当前方法。
        // 为了避免一次性的大量数据关联，规避因此而造成的系统运行性能冲击，这里手动进行了分批次读取，开发者可按需修改该值。
        int batchSize = resultList instanceof Page ? 0 : 1000;
        this.buildRelationForDataList(resultList, MyRelationParam.normal(), batchSize);
        return resultList;
    }

    private SerbiaCountryCode buildDefaultValue(SerbiaCountryCode serbiaCountryCode) {
        if (serbiaCountryCode.getId() == null) {
            serbiaCountryCode.setId(idGenerator.nextLongId());
        }
        MyModelUtil.fillCommonsForInsert(serbiaCountryCode);
        serbiaCountryCode.setDataState(GlobalDeletedFlag.NORMAL);
        return serbiaCountryCode;
    }
}
