package com.serbia.webadmin.app.service.impl;

import cn.hutool.core.collection.CollUtil;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.serbia.webadmin.app.service.*;
import com.serbia.webadmin.app.dao.*;
import com.serbia.webadmin.app.model.*;
import com.serbia.common.core.base.dao.BaseDaoMapper;
import com.serbia.common.core.constant.GlobalDeletedFlag;
import com.serbia.common.core.object.MyRelationParam;
import com.serbia.common.core.object.CallResult;
import com.serbia.common.core.base.service.BaseService;
import com.serbia.common.core.util.MyModelUtil;
import com.serbia.common.sequence.wrapper.IdGeneratorWrapper;
import com.serbia.common.dict.service.GlobalDictService;
import com.github.pagehelper.Page;
import lombok.extern.slf4j.Slf4j;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

/**
 * 聊天群组成员管理数据操作服务类。
 *
 * @author 吃饭睡觉
 * @date 2024-12-10
 */
@Slf4j
@Service("serbiaGroupMembersService")
public class SerbiaGroupMembersServiceImpl extends BaseService<SerbiaGroupMembers, Long> implements SerbiaGroupMembersService {

    @Autowired
    private IdGeneratorWrapper idGenerator;
    @Autowired
    private SerbiaGroupMembersMapper serbiaGroupMembersMapper;
    @Autowired
    private GlobalDictService globalDictService;

    /**
     * 返回当前Service的主表Mapper对象。
     *
     * @return 主表Mapper对象。
     */
    @Override
    protected BaseDaoMapper<SerbiaGroupMembers> mapper() {
        return serbiaGroupMembersMapper;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public SerbiaGroupMembers saveNew(SerbiaGroupMembers serbiaGroupMembers) {
        serbiaGroupMembersMapper.insert(this.buildDefaultValue(serbiaGroupMembers));
        return serbiaGroupMembers;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void saveNewBatch(List<SerbiaGroupMembers> serbiaGroupMembersList) {
        if (CollUtil.isNotEmpty(serbiaGroupMembersList)) {
            serbiaGroupMembersList.forEach(this::buildDefaultValue);
            serbiaGroupMembersMapper.insertList(serbiaGroupMembersList);
        }
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean update(SerbiaGroupMembers serbiaGroupMembers, SerbiaGroupMembers originalSerbiaGroupMembers) {
        MyModelUtil.fillCommonsForUpdate(serbiaGroupMembers, originalSerbiaGroupMembers);
        // 这里重点提示，在执行主表数据更新之前，如果有哪些字段不支持修改操作，请用原有数据对象字段替换当前数据字段。
        UpdateWrapper<SerbiaGroupMembers> uw = this.createUpdateQueryForNullValue(serbiaGroupMembers, serbiaGroupMembers.getId());
        return serbiaGroupMembersMapper.update(serbiaGroupMembers, uw) == 1;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean remove(Long id) {
        return serbiaGroupMembersMapper.deleteById(id) == 1;
    }

    @Override
    public List<SerbiaGroupMembers> getSerbiaGroupMembersList(SerbiaGroupMembers filter, String orderBy) {
        return serbiaGroupMembersMapper.getSerbiaGroupMembersList(filter, orderBy);
    }

    @Override
    public List<SerbiaGroupMembers> getSerbiaGroupMembersListWithRelation(SerbiaGroupMembers filter, String orderBy) {
        List<SerbiaGroupMembers> resultList = serbiaGroupMembersMapper.getSerbiaGroupMembersList(filter, orderBy);
        // 在缺省生成的代码中，如果查询结果resultList不是Page对象，说明没有分页，那么就很可能是数据导出接口调用了当前方法。
        // 为了避免一次性的大量数据关联，规避因此而造成的系统运行性能冲击，这里手动进行了分批次读取，开发者可按需修改该值。
        int batchSize = resultList instanceof Page ? 0 : 1000;
        this.buildRelationForDataList(resultList, MyRelationParam.normal(), batchSize);
        return resultList;
    }

    @Override
    public CallResult verifyRelatedData(SerbiaGroupMembers serbiaGroupMembers, SerbiaGroupMembers originalSerbiaGroupMembers) {
        String errorMessageFormat = "数据验证失败，关联的%s并不存在，请刷新后重试！";
        //这里是基于字典的验证。
        if (this.needToVerify(serbiaGroupMembers, originalSerbiaGroupMembers, SerbiaGroupMembers::getGroupRole)
                && !globalDictService.existDictItemFromCache("GroupMemberRole", serbiaGroupMembers.getGroupRole())) {
            return CallResult.error(String.format(errorMessageFormat, "成员角色 1群主 2群成员"));
        }
        return CallResult.ok();
    }

    private SerbiaGroupMembers buildDefaultValue(SerbiaGroupMembers serbiaGroupMembers) {
        if (serbiaGroupMembers.getId() == null) {
            serbiaGroupMembers.setId(idGenerator.nextLongId());
        }
        MyModelUtil.fillCommonsForInsert(serbiaGroupMembers);
        serbiaGroupMembers.setDataState(GlobalDeletedFlag.NORMAL);
        return serbiaGroupMembers;
    }
}
