package com.serbia.webadmin.app.service.impl;

import cn.hutool.core.collection.CollUtil;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.serbia.webadmin.app.service.*;
import com.serbia.webadmin.app.dao.*;
import com.serbia.webadmin.app.model.*;
import com.serbia.common.core.base.dao.BaseDaoMapper;
import com.serbia.common.core.constant.GlobalDeletedFlag;
import com.serbia.common.core.object.MyRelationParam;
import com.serbia.common.core.object.CallResult;
import com.serbia.common.core.base.service.BaseService;
import com.serbia.common.core.util.MyModelUtil;
import com.serbia.common.sequence.wrapper.IdGeneratorWrapper;
import com.serbia.common.dict.service.GlobalDictService;
import com.github.pagehelper.Page;
import lombok.extern.slf4j.Slf4j;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

/**
 * 聊天群组管理数据操作服务类。
 *
 * @author 吃饭睡觉
 * @date 2024-12-10
 */
@Slf4j
@Service("serbiaGroupsService")
public class SerbiaGroupsServiceImpl extends BaseService<SerbiaGroups, Long> implements SerbiaGroupsService {

    @Autowired
    private IdGeneratorWrapper idGenerator;
    @Autowired
    private SerbiaGroupsMapper serbiaGroupsMapper;
    @Autowired
    private GlobalDictService globalDictService;

    /**
     * 返回当前Service的主表Mapper对象。
     *
     * @return 主表Mapper对象。
     */
    @Override
    protected BaseDaoMapper<SerbiaGroups> mapper() {
        return serbiaGroupsMapper;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public SerbiaGroups saveNew(SerbiaGroups serbiaGroups) {
        serbiaGroupsMapper.insert(this.buildDefaultValue(serbiaGroups));
        return serbiaGroups;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void saveNewBatch(List<SerbiaGroups> serbiaGroupsList) {
        if (CollUtil.isNotEmpty(serbiaGroupsList)) {
            serbiaGroupsList.forEach(this::buildDefaultValue);
            serbiaGroupsMapper.insertList(serbiaGroupsList);
        }
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean update(SerbiaGroups serbiaGroups, SerbiaGroups originalSerbiaGroups) {
        MyModelUtil.fillCommonsForUpdate(serbiaGroups, originalSerbiaGroups);
        // 这里重点提示，在执行主表数据更新之前，如果有哪些字段不支持修改操作，请用原有数据对象字段替换当前数据字段。
        UpdateWrapper<SerbiaGroups> uw = this.createUpdateQueryForNullValue(serbiaGroups, serbiaGroups.getGroupId());
        return serbiaGroupsMapper.update(serbiaGroups, uw) == 1;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean remove(Long groupId) {
        return serbiaGroupsMapper.deleteById(groupId) == 1;
    }

    @Override
    public List<SerbiaGroups> getSerbiaGroupsList(SerbiaGroups filter, String orderBy) {
        return serbiaGroupsMapper.getSerbiaGroupsList(filter, orderBy);
    }

    @Override
    public List<SerbiaGroups> getSerbiaGroupsListWithRelation(SerbiaGroups filter, String orderBy) {
        List<SerbiaGroups> resultList = serbiaGroupsMapper.getSerbiaGroupsList(filter, orderBy);
        // 在缺省生成的代码中，如果查询结果resultList不是Page对象，说明没有分页，那么就很可能是数据导出接口调用了当前方法。
        // 为了避免一次性的大量数据关联，规避因此而造成的系统运行性能冲击，这里手动进行了分批次读取，开发者可按需修改该值。
        int batchSize = resultList instanceof Page ? 0 : 1000;
        this.buildRelationForDataList(resultList, MyRelationParam.normal(), batchSize);
        return resultList;
    }

    @Override
    public CallResult verifyRelatedData(SerbiaGroups serbiaGroups, SerbiaGroups originalSerbiaGroups) {
        String errorMessageFormat = "数据验证失败，关联的%s并不存在，请刷新后重试！";
        //这里是基于字典的验证。
        if (this.needToVerify(serbiaGroups, originalSerbiaGroups, SerbiaGroups::getIsPrivate)
                && !globalDictService.existDictItemFromCache("YesOrNo", serbiaGroups.getIsPrivate())) {
            return CallResult.error(String.format(errorMessageFormat, "是否公开 0私密 1公开"));
        }
        return CallResult.ok();
    }

    private SerbiaGroups buildDefaultValue(SerbiaGroups serbiaGroups) {
        if (serbiaGroups.getGroupId() == null) {
            serbiaGroups.setGroupId(idGenerator.nextLongId());
        }
        MyModelUtil.fillCommonsForInsert(serbiaGroups);
        serbiaGroups.setDataState(GlobalDeletedFlag.NORMAL);
        MyModelUtil.setDefaultValue(serbiaGroups, "isPrivate", 0);
        return serbiaGroups;
    }
}
