package com.serbia.webadmin.app.service.impl;

import cn.hutool.core.collection.CollUtil;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.serbia.webadmin.app.service.*;
import com.serbia.webadmin.app.dao.*;
import com.serbia.webadmin.app.model.*;
import com.serbia.common.core.base.dao.BaseDaoMapper;
import com.serbia.common.core.constant.GlobalDeletedFlag;
import com.serbia.common.core.object.TokenData;
import com.serbia.common.core.object.MyRelationParam;
import com.serbia.common.core.object.CallResult;
import com.serbia.common.core.base.service.BaseService;
import com.serbia.common.sequence.wrapper.IdGeneratorWrapper;
import com.serbia.common.dict.service.GlobalDictService;
import com.github.pagehelper.Page;
import lombok.extern.slf4j.Slf4j;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

/**
 * 聊天信息管理数据操作服务类。
 *
 * @author 吃饭睡觉
 * @date 2024-12-10
 */
@Slf4j
@Service("serbiaMessagesService")
public class SerbiaMessagesServiceImpl extends BaseService<SerbiaMessages, Long> implements SerbiaMessagesService {

    @Autowired
    private IdGeneratorWrapper idGenerator;
    @Autowired
    private SerbiaMessagesMapper serbiaMessagesMapper;
    @Autowired
    private GlobalDictService globalDictService;

    /**
     * 返回当前Service的主表Mapper对象。
     *
     * @return 主表Mapper对象。
     */
    @Override
    protected BaseDaoMapper<SerbiaMessages> mapper() {
        return serbiaMessagesMapper;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public SerbiaMessages saveNew(SerbiaMessages serbiaMessages) {
        serbiaMessagesMapper.insert(this.buildDefaultValue(serbiaMessages));
        return serbiaMessages;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void saveNewBatch(List<SerbiaMessages> serbiaMessagesList) {
        if (CollUtil.isNotEmpty(serbiaMessagesList)) {
            serbiaMessagesList.forEach(this::buildDefaultValue);
            serbiaMessagesMapper.insertList(serbiaMessagesList);
        }
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean update(SerbiaMessages serbiaMessages, SerbiaMessages originalSerbiaMessages) {
        serbiaMessages.setUpdateUserId(TokenData.takeFromRequest().getUserId());
        serbiaMessages.setCreateTime(originalSerbiaMessages.getCreateTime());
        serbiaMessages.setUpdateTime(new Date());
        // 这里重点提示，在执行主表数据更新之前，如果有哪些字段不支持修改操作，请用原有数据对象字段替换当前数据字段。
        UpdateWrapper<SerbiaMessages> uw = this.createUpdateQueryForNullValue(serbiaMessages, serbiaMessages.getMessageId());
        return serbiaMessagesMapper.update(serbiaMessages, uw) == 1;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean remove(Long messageId) {
        return serbiaMessagesMapper.deleteById(messageId) == 1;
    }

    @Override
    public List<SerbiaMessages> getSerbiaMessagesList(SerbiaMessages filter, String orderBy) {
        return serbiaMessagesMapper.getSerbiaMessagesList(filter, orderBy);
    }

    @Override
    public List<SerbiaMessages> getSerbiaMessagesListWithRelation(SerbiaMessages filter, String orderBy) {
        List<SerbiaMessages> resultList = serbiaMessagesMapper.getSerbiaMessagesList(filter, orderBy);
        // 在缺省生成的代码中，如果查询结果resultList不是Page对象，说明没有分页，那么就很可能是数据导出接口调用了当前方法。
        // 为了避免一次性的大量数据关联，规避因此而造成的系统运行性能冲击，这里手动进行了分批次读取，开发者可按需修改该值。
        int batchSize = resultList instanceof Page ? 0 : 1000;
        this.buildRelationForDataList(resultList, MyRelationParam.normal(), batchSize);
        return resultList;
    }

    @Override
    public CallResult verifyRelatedData(SerbiaMessages serbiaMessages, SerbiaMessages originalSerbiaMessages) {
        String errorMessageFormat = "数据验证失败，关联的%s并不存在，请刷新后重试！";
        //这里是基于字典的验证。
        if (this.needToVerify(serbiaMessages, originalSerbiaMessages, SerbiaMessages::getMesssageType)
                && !globalDictService.existDictItemFromCache("MessageType", serbiaMessages.getMesssageType())) {
            return CallResult.error(String.format(errorMessageFormat, "消息类型 1文字 2图片 3文件"));
        }
        return CallResult.ok();
    }

    private SerbiaMessages buildDefaultValue(SerbiaMessages serbiaMessages) {
        if (serbiaMessages.getMessageId() == null) {
            serbiaMessages.setMessageId(idGenerator.nextLongId());
        }
        TokenData tokenData = TokenData.takeFromRequest();
        serbiaMessages.setUpdateUserId(tokenData.getUserId());
        Date now = new Date();
        serbiaMessages.setCreateTime(now);
        serbiaMessages.setUpdateTime(now);
        serbiaMessages.setDataState(GlobalDeletedFlag.NORMAL);
        return serbiaMessages;
    }
}
