package com.serbia.common.flow.util;

import cn.hutool.core.lang.Assert;
import com.serbia.common.flow.base.service.BaseFlowOnlineService;
import com.serbia.common.flow.model.FlowWorkOrder;
import lombok.Setter;
import lombok.extern.slf4j.Slf4j;

/**
 * 面向在线表单工作流的业务数据扩展帮助实现类。
 *
 * @author 吃饭睡觉
 * @date 2024-12-10
 */
@Slf4j
@Setter
public class BaseOnlineBusinessDataExtHelper {

    private BaseFlowOnlineService onlineBusinessService;

    /**
     * 更新在线表单主表数据的流程状态字段值。
     *
     * @param workOrder 工单对象。
     */
    public void updateFlowStatus(FlowWorkOrder workOrder) {
        Assert.notNull(workOrder.getOnlineTableId());
        if (this.onlineBusinessService != null && workOrder.getBusinessKey() != null) {
            onlineBusinessService.updateFlowStatus(workOrder);
        }
    }

    /**
     * 根据工单对象级联删除业务数据。
     *
     * @param workOrder 工单对象。
     */
    public void deleteBusinessData(FlowWorkOrder workOrder) {
        Assert.notNull(workOrder.getOnlineTableId());
        if (this.onlineBusinessService != null && workOrder.getBusinessKey() != null) {
            onlineBusinessService.deleteBusinessData(workOrder);
        }
    }
}
